@@ -1,20 +1,20 @@
 /**
  * Copyright (c) Istituto Nazionale di Fisica Nucleare, 2006-2014.
  *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
+ * in compliance with the License. You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ * http://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing, software distributed under the License
+ * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
+ * or implied. See the License for the specific language governing permissions and limitations under
+ * the License.
  */
 package org.italiangrid.voms.clients.impl;
 
+import static org.italiangrid.voms.request.impl.FakeVOMSACServiceProperties.FAKE;
+
 import java.io.File;
 import java.io.FileNotFoundException;
 import java.io.IOException;
@@ -27,17 +27,19 @@ import java.util.Date;
 import java.util.LinkedHashSet;
 import java.util.List;
 import java.util.Map;
+import java.util.Objects;
 import java.util.Set;
 import java.util.concurrent.TimeUnit;
 
 import org.bouncycastle.asn1.x509.AttributeCertificate;
-import org.bouncycastle.openssl.PasswordFinder;
+import eu.emi.security.authn.x509.helpers.PasswordSupplier;
 import org.italiangrid.voms.VOMSError;
 import org.italiangrid.voms.VOMSValidators;
 import org.italiangrid.voms.ac.VOMSACValidator;
 import org.italiangrid.voms.ac.ValidationResultListener;
 import org.italiangrid.voms.ac.impl.DefaultVOMSValidator;
 import org.italiangrid.voms.clients.ProxyInitParams;
+import org.italiangrid.voms.clients.strategies.ACResolverStrategy;
 import org.italiangrid.voms.clients.strategies.ProxyInitStrategy;
 import org.italiangrid.voms.clients.strategies.VOMSCommandsParsingStrategy;
 import org.italiangrid.voms.clients.util.PasswordFinders;
@@ -83,9 +85,9 @@ import eu.emi.security.authn.x509.proxy.ProxyUtils;
 
 /**
  * The default VOMS proxy init behaviour.
- * 
+ *
  * @author andreaceccanti
- * 
+ *
  */
 public class DefaultVOMSProxyInitBehaviour implements ProxyInitStrategy {
 
@@ -103,17 +105,14 @@ public class DefaultVOMSProxyInitBehaviour implements ProxyInitStrategy {
   private StoreUpdateListener storeUpdateListener;
   private VOMSProtocolListener protocolListener;
 
-  public DefaultVOMSProxyInitBehaviour(
-    VOMSCommandsParsingStrategy commandsParser,
-    ValidationResultListener validationListener,
-    VOMSRequestListener requestListener,
-    ProxyCreationListener pxCreationListener,
-    VOMSServerInfoStoreListener serverInfoStoreListener,
-    LoadCredentialsEventListener loadCredEventListener,
-    ValidationErrorListener certChainListener,
-    VOMSTrustStoreStatusListener vomsTSListener,
-    StoreUpdateListener trustStoreUpdateListener,
-    VOMSProtocolListener protocolListener) {
+  private ACResolverStrategy acResolver;
+
+  public DefaultVOMSProxyInitBehaviour(VOMSCommandsParsingStrategy commandsParser,
+      ValidationResultListener validationListener, VOMSRequestListener requestListener,
+      ProxyCreationListener pxCreationListener, VOMSServerInfoStoreListener serverInfoStoreListener,
+      LoadCredentialsEventListener loadCredEventListener, ValidationErrorListener certChainListener,
+      VOMSTrustStoreStatusListener vomsTSListener, StoreUpdateListener trustStoreUpdateListener,
+      VOMSProtocolListener protocolListener) {
 
     this.commandsParser = commandsParser;
     this.validationResultListener = validationListener;
@@ -125,11 +124,12 @@ public class DefaultVOMSProxyInitBehaviour implements ProxyInitStrategy {
     this.vomsTrustStoreListener = vomsTSListener;
     this.storeUpdateListener = trustStoreUpdateListener;
     this.protocolListener = protocolListener;
+
+
   }
 
-  public DefaultVOMSProxyInitBehaviour(
-    VOMSCommandsParsingStrategy commandsParser,
-    InitListenerAdapter listenerAdapter) {
+  public DefaultVOMSProxyInitBehaviour(VOMSCommandsParsingStrategy commandsParser,
+      InitListenerAdapter listenerAdapter) {
 
     this.commandsParser = commandsParser;
     this.validationResultListener = listenerAdapter;
@@ -143,11 +143,9 @@ public class DefaultVOMSProxyInitBehaviour implements ProxyInitStrategy {
     this.protocolListener = listenerAdapter;
   }
 
-  protected void validateUserCredential(ProxyInitParams params,
-    X509Credential cred) {
+  protected void validateUserCredential(ProxyInitParams params, X509Credential cred) {
 
-    ValidationResult result = certChainValidator
-      .validate(cred.getCertificateChain());
+    ValidationResult result = certChainValidator.validate(cred.getCertificateChain());
     if (!result.isValid())
       throw new VOMSError("User credential is not valid!");
 
@@ -155,22 +153,34 @@ public class DefaultVOMSProxyInitBehaviour implements ProxyInitStrategy {
 
   private void init(ProxyInitParams params) {
 
-    boolean hasVOMSCommands = params.getVomsCommands() != null
-      && !params.getVomsCommands()
-        .isEmpty();
-
-    if (hasVOMSCommands || params.validateUserCredential()) {
+    if (hasVomsCommands(params) || params.validateUserCredential()) {
 
       params.setValidateUserCredential(true);
       initCertChainValidator(params);
 
-      if (params.verifyAC() && hasVOMSCommands) {
+      if (params.verifyAC() && hasVomsCommands(params)) {
         initVOMSValidator(params);
       }
     }
 
   }
 
+  protected void buildACResolver() {
+    
+    if (!Objects.isNull(FAKE.getSystemPropertyValue())) {
+      acResolver = new FakeACResolver(requestListener);
+    }
+    
+    if (Objects.isNull(acResolver)) {
+      acResolver = new DefaultACResolver(commandsParser, certChainValidator, requestListener,
+          protocolListener);
+    }
+  }
+
+  protected boolean hasVomsCommands(ProxyInitParams params) {
+    return !Objects.isNull(params.getVomsCommands()) && !params.getVomsCommands().isEmpty();
+  }
+
   public void initProxy(ProxyInitParams params) {
 
     init(params);
@@ -178,25 +188,27 @@ public class DefaultVOMSProxyInitBehaviour implements ProxyInitStrategy {
     VOMSServerInfoStore serverInfoStore = null;
 
     // Fail fast if VO is not configured correctly
-    if (params.getVomsCommands() != null && !params.getVomsCommands()
-      .isEmpty()) {
+    if (hasVomsCommands(params)) {
       serverInfoStore = initServerInfoStore(params);
       checkCommands(params, serverInfoStore);
     }
 
     X509Credential cred = lookupCredential(params);
-    if (cred == null)
+    if (cred == null) {
       throw new VOMSError("No credentials found!");
+    }
 
-    if (params.validateUserCredential())
+    if (params.validateUserCredential()) {
       validateUserCredential(params, cred);
+    }
 
     List<AttributeCertificate> acs = Collections.emptyList();
 
-    if (params.getVomsCommands() != null && !params.getVomsCommands()
-      .isEmpty()) {
+    if (hasVomsCommands(params)) {
       initCertChainValidator(params);
-      acs = getAttributeCertificates(params, cred, serverInfoStore);
+      buildACResolver();
+
+      acs = acResolver.getVOMSACs(params, cred, serverInfoStore);
     }
 
     if (params.verifyAC() && !acs.isEmpty()) {
@@ -208,15 +220,14 @@ public class DefaultVOMSProxyInitBehaviour implements ProxyInitStrategy {
 
   private void checkCommands(ProxyInitParams params, VOMSServerInfoStore sis) {
 
-    Map<String, List<String>> vomsCommandsMap = commandsParser
-      .parseCommands(params.getVomsCommands());
+    Map<String, List<String>> vomsCommandsMap =
+        commandsParser.parseCommands(params.getVomsCommands());
 
     for (String voOrAlias : vomsCommandsMap.keySet()) {
-      if (sis.getVOMSServerInfo(voOrAlias)
-        .isEmpty()) {
+      if (sis.getVOMSServerInfo(voOrAlias).isEmpty()) {
 
-        String msg = String.format("VOMS server for VO %s is not known! "
-          + "Check your vomses configuration.", voOrAlias);
+        String msg = String.format(
+            "VOMS server for VO %s is not known! " + "Check your vomses configuration.", voOrAlias);
         throw new VOMSError(msg);
       }
     }
@@ -226,8 +237,7 @@ public class DefaultVOMSProxyInitBehaviour implements ProxyInitStrategy {
 
     VOMSServerInfoStore sis = null;
 
-    if (params.getVomsCommands() != null && !params.getVomsCommands()
-      .isEmpty()) {
+    if (params.getVomsCommands() != null && !params.getVomsCommands().isEmpty()) {
       sis = new DefaultVOMSServerInfoStore.Builder()
         .lookupStrategy(getVOMSESLookupStrategyFromParams(params))
         .storeListener(serverInfoStoreListener)
@@ -245,8 +255,7 @@ public class DefaultVOMSProxyInitBehaviour implements ProxyInitStrategy {
     errorTemplate = errorTemplate + " (%s)";
 
     if (!f.exists()) {
-      Throwable t = new FileNotFoundException(
-        String.format(errorTemplate, "file not found"));
+      Throwable t = new FileNotFoundException(String.format(errorTemplate, "file not found"));
       throw new VOMSError(t.getMessage(), t);
     }
 
@@ -283,9 +292,10 @@ public class DefaultVOMSProxyInitBehaviour implements ProxyInitStrategy {
 
   private VOMSACValidator initVOMSValidator(ProxyInitParams params) {
 
-    if (vomsValidator != null)
+    if (vomsValidator != null) {
       return vomsValidator;
-
+    }
+    
     String vomsdir = DefaultVOMSTrustStore.DEFAULT_VOMS_DIR;
 
     if (System.getenv(VOMSEnvironmentVariables.X509_VOMS_DIR) != null)
@@ -296,17 +306,16 @@ public class DefaultVOMSProxyInitBehaviour implements ProxyInitStrategy {
 
     directorySanityChecks(vomsdir, "Invalid vomsdir location");
 
-    VOMSTrustStore trustStore = new DefaultVOMSTrustStore(
-      Arrays.asList(vomsdir), vomsTrustStoreListener);
+    VOMSTrustStore trustStore =
+        new DefaultVOMSTrustStore(Arrays.asList(vomsdir), vomsTrustStoreListener);
 
-    vomsValidator = VOMSValidators.newValidator(trustStore, certChainValidator,
-      validationResultListener);
+    vomsValidator =
+        VOMSValidators.newValidator(trustStore, certChainValidator, validationResultListener);
 
     return vomsValidator;
   }
 
-  private void verifyACs(ProxyInitParams params,
-    List<AttributeCertificate> acs) {
+  private void verifyACs(ProxyInitParams params, List<AttributeCertificate> acs) {
 
     VOMSACValidator acValidator = initVOMSValidator(params);
     acValidator.validateACs(acs);
@@ -318,42 +327,41 @@ public class DefaultVOMSProxyInitBehaviour implements ProxyInitStrategy {
 
     switch (pt) {
 
-    case DRAFT_RFC:
-      return ProxyType.DRAFT_RFC;
+      case DRAFT_RFC:
+        return ProxyType.DRAFT_RFC;
 
-    case LEGACY:
-      return ProxyType.LEGACY;
+      case LEGACY:
+        return ProxyType.LEGACY;
 
-    case RFC3820:
-      return ProxyType.RFC3820;
+      case RFC3820:
+        return ProxyType.RFC3820;
 
-    default:
-      return null;
+      default:
+        return null;
     }
   }
 
-  private void ensureProxyTypeIsCompatibleWithIssuingCredential(
-    ProxyCertificateOptions options, X509Credential issuingCredential,
-    List<String> proxyCreationWarnings) {
+  private void ensureProxyTypeIsCompatibleWithIssuingCredential(ProxyCertificateOptions options,
+      X509Credential issuingCredential, List<String> proxyCreationWarnings) {
 
     if (ProxyUtils.isProxy(issuingCredential.getCertificateChain())) {
 
       ProxyType issuingProxyType = extendedProxyTypeAsProxyType(
-        ProxyHelper.getProxyType(issuingCredential.getCertificateChain()[0]));
+          ProxyHelper.getProxyType(issuingCredential.getCertificateChain()[0]));
 
       if (!issuingProxyType.equals(options.getType())) {
         proxyCreationWarnings.add("forced " + issuingProxyType.name()
-          + " proxy type to be compatible with the type of the issuing proxy.");
+            + " proxy type to be compatible with the type of the issuing proxy.");
         options.setType(issuingProxyType);
       }
 
       try {
 
-        boolean issuingProxyIsLimited = ProxyHelper
-          .isLimited(issuingCredential.getCertificateChain()[0]);
+        boolean issuingProxyIsLimited =
+            ProxyHelper.isLimited(issuingCredential.getCertificateChain()[0]);
         if (issuingProxyIsLimited && !options.isLimited()) {
           proxyCreationWarnings.add(
-            "forced the creation of a limited proxy to be compatible with the type of the issuing proxy.");
+              "forced the creation of a limited proxy to be compatible with the type of the issuing proxy.");
           limitProxy(options);
         }
 
@@ -370,10 +378,9 @@ public class DefaultVOMSProxyInitBehaviour implements ProxyInitStrategy {
       ProxyChainInfo ci;
       try {
         ci = new ProxyChainInfo(issuingCredential.getCertificateChain());
-        if (ci.getProxyType()
-          .equals(ProxyChainType.MIXED))
+        if (ci.getProxyType().equals(ProxyChainType.MIXED))
           throw new VOMSError(
-            "Cannot generate a proxy certificate starting from a mixed type proxy chain.");
+              "Cannot generate a proxy certificate starting from a mixed type proxy chain.");
 
       } catch (CertificateException e) {
         throw new VOMSError(e.getMessage(), e);
@@ -381,9 +388,8 @@ public class DefaultVOMSProxyInitBehaviour implements ProxyInitStrategy {
     }
   }
 
-  private void ensureProxyLifetimeIsConsistentWithIssuingCredential(
-    ProxyCertificateOptions options, X509Credential issuingCredential,
-    List<String> proxyCreationWarnings) {
+  private void ensureProxyLifetimeIsConsistentWithIssuingCredential(ProxyCertificateOptions options,
+      X509Credential issuingCredential, List<String> proxyCreationWarnings) {
 
     Calendar cal = Calendar.getInstance();
 
@@ -392,15 +398,13 @@ public class DefaultVOMSProxyInitBehaviour implements ProxyInitStrategy {
     cal.add(Calendar.SECOND, options.getLifetime());
 
     Date proxyEndTime = cal.getTime();
-    Date issuingCredentialEndTime = issuingCredential.getCertificate()
-      .getNotAfter();
+    Date issuingCredentialEndTime = issuingCredential.getCertificate().getNotAfter();
 
     options.setValidityBounds(proxyStartTime, proxyEndTime);
 
     if (proxyEndTime.after(issuingCredentialEndTime)) {
 
-      proxyCreationWarnings
-        .add("proxy lifetime limited to issuing " + "credential lifetime.");
+      proxyCreationWarnings.add("proxy lifetime limited to issuing " + "credential lifetime.");
       options.setValidityBounds(proxyStartTime, issuingCredentialEndTime);
     }
   }
@@ -409,23 +413,20 @@ public class DefaultVOMSProxyInitBehaviour implements ProxyInitStrategy {
 
     proxyOptions.setLimited(true);
 
-    if (proxyOptions.getType()
-      .equals(ProxyType.RFC3820)
-      || proxyOptions.getType()
-        .equals(ProxyType.DRAFT_RFC))
+    if (proxyOptions.getType().equals(ProxyType.RFC3820)
+        || proxyOptions.getType().equals(ProxyType.DRAFT_RFC))
       proxyOptions.setPolicy(new ProxyPolicy(ProxyPolicy.LIMITED_PROXY_OID));
 
   }
 
   private void createProxy(ProxyInitParams params, X509Credential credential,
-    List<AttributeCertificate> acs) {
+      List<AttributeCertificate> acs) {
 
     List<String> proxyCreationWarnings = new ArrayList<String>();
 
     String proxyFilePath = VOMSProxyPathBuilder.buildProxyPath();
 
-    String envProxyPath = System
-      .getenv(VOMSEnvironmentVariables.X509_USER_PROXY);
+    String envProxyPath = System.getenv(VOMSEnvironmentVariables.X509_USER_PROXY);
 
     if (envProxyPath != null)
       proxyFilePath = envProxyPath;
@@ -433,8 +434,8 @@ public class DefaultVOMSProxyInitBehaviour implements ProxyInitStrategy {
     if (params.getGeneratedProxyFile() != null)
       proxyFilePath = params.getGeneratedProxyFile();
 
-    ProxyCertificateOptions proxyOptions = new ProxyCertificateOptions(
-      credential.getCertificateChain());
+    ProxyCertificateOptions proxyOptions =
+        new ProxyCertificateOptions(credential.getCertificateChain());
 
     proxyOptions.setProxyPathLimit(params.getPathLenConstraint());
 
@@ -448,41 +449,36 @@ public class DefaultVOMSProxyInitBehaviour implements ProxyInitStrategy {
       checkMixedProxyChain(credential);
 
       ensureProxyTypeIsCompatibleWithIssuingCredential(proxyOptions, credential,
-        proxyCreationWarnings);
+          proxyCreationWarnings);
 
-      ensureProxyLifetimeIsConsistentWithIssuingCredential(proxyOptions,
-        credential, proxyCreationWarnings);
+      ensureProxyLifetimeIsConsistentWithIssuingCredential(proxyOptions, credential,
+          proxyCreationWarnings);
     }
 
     if (params.isLimited())
       limitProxy(proxyOptions);
 
-    if (acs != null && !acs.isEmpty())
-      proxyOptions.setAttributeCertificates(
-        acs.toArray(new AttributeCertificate[acs.size()]));
-
     try {
+      if (acs != null && !acs.isEmpty()) {
+        proxyOptions.setAttributeCertificates(acs.toArray(new AttributeCertificate[acs.size()]));
+      }
 
-      ProxyCertificate proxy = ProxyGenerator.generate(proxyOptions,
-        credential.getKey());
 
-      CredentialsUtils.saveProxyCredentials(proxyFilePath,
-        proxy.getCredential());
-      proxyCreationListener.proxyCreated(proxyFilePath, proxy,
-        proxyCreationWarnings);
+      ProxyCertificate proxy = ProxyGenerator.generate(proxyOptions, credential.getKey());
+
+      CredentialsUtils.saveProxyCredentials(proxyFilePath, proxy.getCredential());
+
+      proxyCreationListener.proxyCreated(proxyFilePath, proxy, proxyCreationWarnings);
 
     } catch (Throwable t) {
 
-      throw new VOMSError("Error creating proxy certificate: " + t.getMessage(),
-        t);
+      throw new VOMSError("Error creating proxy certificate: " + t.getMessage(), t);
     }
   }
 
-  protected List<String> sortFQANsIfRequested(ProxyInitParams params,
-    List<String> unsortedFQANs) {
+  protected List<String> sortFQANsIfRequested(ProxyInitParams params, List<String> unsortedFQANs) {
 
-    if (params.getFqanOrder() != null && !params.getFqanOrder()
-      .isEmpty()) {
+    if (params.getFqanOrder() != null && !params.getFqanOrder().isEmpty()) {
 
       Set<String> fqans = new LinkedHashSet<String>();
       for (String fqan : params.getFqanOrder()) {
@@ -490,8 +486,7 @@ public class DefaultVOMSProxyInitBehaviour implements ProxyInitStrategy {
         if (VOMSFQANNamingScheme.isGroup(fqan))
           fqans.add(fqan);
 
-        if (VOMSFQANNamingScheme.isQualifiedRole(fqan)
-          && unsortedFQANs.contains(fqan))
+        if (VOMSFQANNamingScheme.isQualifiedRole(fqan) && unsortedFQANs.contains(fqan))
           fqans.add(fqan);
 
       }
@@ -504,28 +499,25 @@ public class DefaultVOMSProxyInitBehaviour implements ProxyInitStrategy {
     return unsortedFQANs;
   }
 
-  protected VOMSESLookupStrategy getVOMSESLookupStrategyFromParams(
-    ProxyInitParams params) {
+  protected VOMSESLookupStrategy getVOMSESLookupStrategyFromParams(ProxyInitParams params) {
 
-    if (params.getVomsesLocations() != null && !params.getVomsesLocations()
-      .isEmpty())
+    if (params.getVomsesLocations() != null && !params.getVomsesLocations().isEmpty())
       return new BaseVOMSESLookupStrategy(params.getVomsesLocations());
     else
       return new DefaultVOMSESLookupStrategy();
 
   }
 
-  protected List<AttributeCertificate> getAttributeCertificates(
-    ProxyInitParams params, X509Credential cred,
-    VOMSServerInfoStore serverInfoStore) {
+  protected List<AttributeCertificate> getAttributeCertificates(ProxyInitParams params,
+      X509Credential cred, VOMSServerInfoStore serverInfoStore) {
 
     List<String> vomsCommands = params.getVomsCommands();
 
     if (vomsCommands == null || vomsCommands.isEmpty())
       return Collections.emptyList();
 
-    Map<String, List<String>> vomsCommandsMap = commandsParser
-      .parseCommands(params.getVomsCommands());
+    Map<String, List<String>> vomsCommandsMap =
+        commandsParser.parseCommands(params.getVomsCommands());
 
     List<AttributeCertificate> acs = new ArrayList<AttributeCertificate>();
 
@@ -533,35 +525,31 @@ public class DefaultVOMSProxyInitBehaviour implements ProxyInitStrategy {
 
       List<String> fqans = vomsCommandsMap.get(vo);
 
-      VOMSACRequest request = new DefaultVOMSACRequest.Builder(vo)
-        .fqans(sortFQANsIfRequested(params, fqans))
-        .targets(params.getTargets())
-        .lifetime(params.getAcLifetimeInSeconds())
-        .build();
+      VOMSACRequest request =
+          new DefaultVOMSACRequest.Builder(vo).fqans(sortFQANsIfRequested(params, fqans))
+            .targets(params.getTargets())
+            .lifetime(params.getAcLifetimeInSeconds())
+            .build();
 
-      VOMSACService acService = new DefaultVOMSACService.Builder(
-        certChainValidator).requestListener(requestListener)
-          .serverInfoStore(serverInfoStore)
-          .vomsesLookupStrategy(getVOMSESLookupStrategyFromParams(params))
-          .protocolListener(protocolListener)
-          .connectTimeout(
-            (int) TimeUnit.SECONDS.toMillis(params.getTimeoutInSeconds()))
-          .readTimeout(
-            (int) TimeUnit.SECONDS.toMillis(params.getTimeoutInSeconds()))
-          .skipHostnameChecks(params.isSkipHostnameChecks())
-          .build();
+      VOMSACService acService =
+          new DefaultVOMSACService.Builder(certChainValidator).requestListener(requestListener)
+            .serverInfoStore(serverInfoStore)
+            .vomsesLookupStrategy(getVOMSESLookupStrategyFromParams(params))
+            .protocolListener(protocolListener)
+            .connectTimeout((int) TimeUnit.SECONDS.toMillis(params.getTimeoutInSeconds()))
+            .readTimeout((int) TimeUnit.SECONDS.toMillis(params.getTimeoutInSeconds()))
+            .skipHostnameChecks(params.isSkipHostnameChecks())
+            .build();
 
-      AttributeCertificate ac = acService.getVOMSAttributeCertificate(cred,
-        request);
+      AttributeCertificate ac = acService.getVOMSAttributeCertificate(cred, request);
 
-      if (ac != null)
+      if (ac != null) {
         acs.add(ac);
+      }
     }
 
-    if (!vomsCommandsMap.keySet()
-      .isEmpty() && acs.isEmpty())
-      throw new VOMSError(
-        "User's request for VOMS attributes could not be fulfilled.");
+    if (!vomsCommandsMap.keySet().isEmpty() && acs.isEmpty())
+      throw new VOMSError("User's request for VOMS attributes could not be fulfilled.");
 
     return acs;
   }
@@ -569,32 +557,28 @@ public class DefaultVOMSProxyInitBehaviour implements ProxyInitStrategy {
   private LoadCredentialsStrategy strategyFromParams(ProxyInitParams params) {
 
     if (params.isNoRegen()) {
-      return new LoadProxyCredential(loadCredentialsEventListener,
-        params.getCertFile());
+      return new LoadProxyCredential(loadCredentialsEventListener, params.getCertFile());
     }
 
     if (params.getCertFile() != null && params.getKeyFile() == null)
-      return new LoadUserCredential(loadCredentialsEventListener,
-        params.getCertFile());
+      return new LoadUserCredential(loadCredentialsEventListener, params.getCertFile());
 
     if (params.getCertFile() != null && params.getKeyFile() != null)
-      return new LoadUserCredential(loadCredentialsEventListener,
-        params.getCertFile(), params.getKeyFile());
+      return new LoadUserCredential(loadCredentialsEventListener, params.getCertFile(),
+          params.getKeyFile());
 
     return new DefaultLoadCredentialsStrategy(
-      System.getProperty(DefaultLoadCredentialsStrategy.HOME_PROPERTY),
-      DefaultLoadCredentialsStrategy.TMPDIR_PROPERTY,
-      loadCredentialsEventListener);
+        System.getProperty(DefaultLoadCredentialsStrategy.HOME_PROPERTY),
+        DefaultLoadCredentialsStrategy.TMPDIR_PROPERTY, loadCredentialsEventListener);
 
   }
 
   private X509Credential lookupCredential(ProxyInitParams params) {
 
-    PasswordFinder pf = null;
+    PasswordSupplier pf = null;
 
     if (params.isReadPasswordFromStdin())
-      pf = PasswordFinders.getNoPromptInputStreamPasswordFinder(System.in,
-        System.out);
+      pf = PasswordFinders.getNoPromptInputStreamPasswordFinder(System.in, System.out);
     else
       pf = PasswordFinders.getDefault();
 
@@ -602,5 +586,4 @@ public class DefaultVOMSProxyInitBehaviour implements ProxyInitStrategy {
 
     return loadCredStrategy.loadCredentials(pf);
   }
-
 }
